Image scales
scale_image_identity(..., guide = "none", aesthetics = "image")scale_image_manual(..., values, aesthetics = "image")
Other arguments passed on to discrete_scale() or
continuous_scale()
Guide to use for this scale. Defaults to "none".
Character string or vector of character strings listing the
name(s) of the aesthetic(s) that this scale works with. This can be useful, for
example, to apply colour settings to the colour and fill aesthetics at the
same time, via aesthetics = c("colour", "fill").
a set of aesthetic values to map data values to. The values
will be matched in order (usually alphabetical) with the limits of the
scale, or with breaks if provided. If this is a named vector, then the
values will be matched based on the names instead. Data values that don't
match will be given na.value.